@@ -5,6 +5,15 @@
   var has_fancy_scrollbars = /(iPad|iPhone|iPod)/g.test(navigator.userAgent);
   var $height_from, $win;
 
+  var confirmFirst = function() {
+    var $a = $(this);
+    var confirm_text = 'Click again to confirm';
+    var original_text = $a.text();
+    if(original_text == confirm_text) return true;
+    $a.text(confirm_text).one('mouseleave', function() { $a.text(original_text); });
+    return false;
+  };
+
   $.supportsTouch = 'ontouchstart' in window || navigator.msMaxTouchPoints;
 
   $.notify = function(title, body, icon) {
@@ -36,18 +45,27 @@
     return this;
   };
 
+  $.fn.focusSoon = function() {
+    var $e = this.eq(0);
+    setTimeout(function() { $e.focus(); }, 100);
+    return this;
+  };
+
   $.fn.initDropDown = function() {
     return this.each(function() {
       var $a = $(this);
       var $container = $( $a.data('toggle') );
-      var scroller = $container.hasClass('scrolled');
+
+      if(!has_fancy_scrollbars) {
+        $container.addClass('nanoscroller').wrapInner('<div class="content"/>').nanoScroller({ preventPageScrolling: true });
+      }
 
       $a.on('activate', function() {
         var $a = $(this);
         var height = $win.height() - 70;
         var left = $a.offset().left + $a.outerWidth() - $container.width();
-        $container.css('left', left < 10 ? 10 : left);
-        if(scroller) $container.height(height);
+        if(left < 10) left = 10;
+        $container.css({ left: left, height: height }).nanoScroller();
       });
     });
   };
@@ -80,13 +98,11 @@
     var $active = $('a[data-toggle]').filter('.active');
     if(!$active.length) return true;
     if($(e.target).closest($active).length) return true; // prevent hiding when clicking inside forms
-    if($(e.target).closest('form').length) return true; // prevent hiding when clicking inside forms
     $active.trigger('deactivate');
     return false;
   };
 
-  $.fn.toggleElementWithClick = function(e) {
-    if(e) e.preventDefault();
+  $.fn.toggleElementWithClick = function() {
     return this.each(function() {
       var $a = $(this);
       var focus = $a.attr('data-focus');
@@ -101,6 +117,7 @@
         var $target = $(target);
         var is_active = $a.hasClass('active');
 
+        $(document).off('click', hideToggledElement);
         $('a[data-toggle]').filter('.active').trigger('deactivate');
         if(is_active) return false;
 
@@ -109,7 +126,8 @@
           $target.show();
           $a.data('target', $target).trigger('activate').addClass('active');
           inside = false;
-          if(focus) $(focus, target).eq(0).focus();
+          if(focus) $(focus, target).eq(0).focusSoon();
+          if(!$target.hasClass('ignore-document-close')) $(document).one('click', hideToggledElement);
         }
 
         return false;
@@ -119,7 +137,6 @@
 
   $.url_for = function() {
     var args = $.makeArray(arguments);
-    args[0] = args[0].replace(/^\//, '');
     args.unshift($('html').data('basepath').replace(/\/$/, ''));
     return args.join('/').replace(/#/g, '%23');
   };
@@ -129,7 +146,7 @@
     var $focus = $togglers.filter('.active').trigger('activate').filter('.focus');
     var $login_button = $('a[data-toggle="div.login"]');
 
-    $(document).on('click', hideToggledElement);
+    $('a.confirm').click(confirmFirst);
 
     if($login_button.length) {
       $('body').bind('keydown', 'shift+return', function(e) {
@@ -137,6 +154,9 @@
         $login_button.click();
       });
     }
+    if(has_fancy_scrollbars) {
+      $.fn.nanoScroller = function() { return this; };
+    }
 
     $height_from = $('div.wrapper').length ? $('div.wrapper') : $('body');
     $win = $(window).data('at_bottom', false).data('has_focus', true);
